<img width='90%' alt='Kiqpo-python web ui framework applications' src='https://www.linkpicture.com/q/kiqpo_1.svg'/>
<br/>
<br/>


<p align="center">
  <img width='10%' src='https://www.linkpicture.com/q/icon-kiqpo.png' />
</p>
<h3 align="center" >Kiqpo</h3>
<b align="center">
    <p align="center">Build web apps faster than ever</p>
</b>

### Quick start

> ⚠️ Kiqpo is **Unsuitable for production** as of now.

<sub>Try and contribute | pre-alpha</sub>





- [Installation](https://github.com/kiqpo/pre-alpha/blob/main/doc/Installation.md)
- [Usage](https://github.com/kiqpo/pre-alpha/blob/main/doc/Usage.md)
- [Contribution](https://github.com/kiqpo/pre-alpha/blob/main/doc/CONTRIBUTING.md)
- [Documentation](http://kiqpo.software)

### About Kiqpo

By making use of [KIQPO](https://github/kiqpo), you can build beautiful, fast, and reliable web applications without relying on [JavaScript](https://github.com/topics/javascript) frameworks, [HTML](https://github.com/topics/HTML) templates, request parsing, or state management. All of this is done using [Python](https://github.com/python) and we're targeting web, [Windows](https://github.com/microsoft), [macOS](https://github.com/topics/macos), [Linux](https://github.com/topics/linux) platforms

### Beautiful user interface

We want to enable designers to deliver their full creative vision without being forced to water it down due to limitations of the underlying framework.
that's why we follow [google](https://github.com/google)'s [material design](https://github.com/material-components) system.
<!-- ![ezgif-com-gif-maker.gif](https://postimg.cc/sMN0v82Z) -->

### Productive development

Kiqpo offers hot reload, allowing you to make changes to your code and see the results instantly & No HTML/CSS/JavaScript required for Kiqpo

<img width='100%' src='https://i.postimg.cc/c1rXZYxL/output-onlinegiftools.gif' />

<br/>
Kiqpo is a fully open-source project, and we welcome contributions. Information on how to get started can be found in our contributor guide.
